/*
 * Copyright 2015 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package jsinterop.annotations;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * JsOverlay is used to add new helper APIs to existing JavaScript types. This is achieved by adding
 * the new method/field to a @JsType(isNative=true) and marking it with this annotation.
 * <p>
 * Note that the JsOverlay methods cannot be called from JavaScript, cannot override any existing
 * methods and needs to be marked as final. This is because underneath, the original type is not
 * modified and the method is simply turned into a static dispatch. Similarly, JsOverlay fields can
 * only be compile time constants.
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.METHOD, ElementType.FIELD})
@Documented
public @interface JsOverlay {
}
